# -*- coding: utf-8 -*-

import datetime

from django.conf import settings
from django.db.models import Sum


class InvoiceMixin(object):
    if 'jmb.invoice' in settings.INSTALLED_APPS:
        def get_invoicerows(self, date_begin=None, date_end=None):
            """
            Returns a list of invoicerows in a certain period
            """
            if not date_begin:
                date_begin = datetime.date.today()
            if not date_end:
                date_end = datetime.date.today()
            invoices = self.owner_invoices.filter(date_i__gte=date_begin, date_i__lte=date_end)
            total_rows = []
            for invoice in invoices:
                rows = invoice.rows.all()
                total_rows.extend(rows)
            return total_rows

        def get_total_invoiced(self, year=None):
            """
            Returns total income, total fee and total discount of year set
            """
            if not year:
                year = datetime.date.today().year
            totals = self.owner_invoices.filter(
                date_i__year="{year}".format(year=year)
            ).aggregate(
                Sum('total_income'), Sum('total_fee'),
                Sum('total_discount'), Sum('total_vat')
            )
            totals['year'] = year
            try:
                totals['totals__sum'] = (
                    totals['total_income__sum'] + totals['total_fee__sum'] -
                    totals['total_discount__sum'] + totals['total_vat__sum']
                )
            except:
                totals['totals__sum'] = None
            return totals

        def get_year_invoiced(self):
            """
            Returns invoice totals of the last 3 years
            """
            l = []
            year = datetime.date.today().year
            for y in [year, year - 1, year - 2]:
                l.append(self.get_total_invoiced(y))
            return l
