# -*- coding: utf-8 -*-

import datetime

from django.conf import settings
from django.db.models import Sum


class ProcedureMixin(object):
    if 'jmb.procedure' in settings.INSTALLED_APPS:
        def get_procedurerows(self, date_begin=None, date_end=None):
            """
            Returns a list of procedurerows in a certain period
            """
            if not date_begin: date_begin = datetime.date.today()
            if not date_end: date_end = datetime.date.today()
            procedures = self.procedures.filter(date_p__gte=date_begin, date_p__lte=date_end)
            total_rows = []
            for procedure in procedures:
                rows = procedure.rows.all()
                total_rows.extend(rows)
            return total_rows

        def get_total_ordered(self, year=None):
            if not year:
                year = datetime.date.today().year
            totals = self.owner_procedures.filter(date_p__year="{year}".format(year=year)).aggregate(
                Sum('total_income'),
                Sum('total_fee'),
                Sum('total_discount'),
                Sum('total_vat')
            )
            totals['year'] = year

            # Aggiungo al totale degli ordini anche un eventuale totale ordinato (o fatturato,
            # qua e' da capire bene, xke x mentasti il fatturato e' l'ordinato) dell'anno
            # che rappresenta un'eventuale quantita iniziale settata se si inizia ad usare il
            # programma a meta' anno
            #
            total_invoice = self.total_invoiced.filter(year=year)
            if total_invoice:
                total_invoice = total_invoice[0].total
            else:
                total_invoice = 0

            try:
                totals['totals__sum'] = (
                    (totals['total_income__sum'] or 0) +
                    (totals['total_fee__sum'] or 0) -
                    (totals['total_discount__sum'] or 0) +
                    (totals['total_vat__sum'] or 0) +
                    total_invoice
                )
            except Exception as e:
                totals['totals__sum'] = None
            return totals

        def get_year_ordered(self, num_year=4):
            """
            Returns a list of proceure's totals in the last 4 years
            """
            l = []
            first_year = datetime.date.today().year - num_year + 1
            last_year = datetime.date.today().year + 1

            for y in reversed(range(first_year, last_year)):
                l.append(self.get_total_ordered(y))
            return l
